/*
 * RHQ Management Platform
 * Copyright (C) 2012 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.rhq.enterprise.startup;

import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.DEPLOYMENT;

import java.net.URL;
import java.util.Set;

import org.jboss.as.controller.AbstractAddStepHandler;
import org.jboss.as.controller.OperationContext;
import org.jboss.as.controller.OperationFailedException;
import org.jboss.as.controller.PathAddress;
import org.jboss.as.controller.PathElement;
import org.jboss.as.controller.registry.Resource;
import org.jboss.dmr.ModelNode;
import org.jboss.modules.Module;

/**
 * Handler responsible for adding the subsystem resource to the model
 *
 * @author John Mazzitelli
 */
class StartupSubsystemAdd extends AbstractAddStepHandler {

    static final StartupSubsystemAdd INSTANCE = new StartupSubsystemAdd();

    @Override
    protected void populateModel(OperationContext context, ModelNode operation, Resource resource)
        throws OperationFailedException {

        if (requiresRuntime(context)) { // only add the step if we are going to actually deploy the ear
            PathAddress deploymentAddress = PathAddress.pathAddress(PathElement.pathElement(DEPLOYMENT,
                StartupExtension.DEPLOYMENT_APP_EAR));

            Module module = Module.forClass(getClass());

            URL url = module.getExportedResource(StartupExtension.DEPLOYMENT_APP_EAR);
            System.out.println("~~~~~~~~~~~~~URL: " + url);
            Set<String> paths = module.getExportedPaths();
            System.out.println("~~~~~~~~~~~~~paths has ear: " + paths.contains(StartupExtension.DEPLOYMENT_APP_EAR));

            return;
        }
    }

    @Override
    protected void populateModel(ModelNode operation, ModelNode model) throws OperationFailedException {
        // We overrode the code that calls this method
        throw new UnsupportedOperationException();
    }

    @Override
    protected boolean requiresRuntimeVerification() {
        return false;
    }
}
